@@ -2,8 +2,8 @@ package t::lib::Export;
 use strict;
 use warnings;
 
-use base 'Exporter';
-
+use Exporter;
+our @ISA    = qw/Exporter/;
 our @EXPORT = qw/foo/;
 
 sub foo { 1 }
